==> rc-ui-lib-1.3.4.tgz: package/es/hooks/use-click-away.js <==
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
import { useEffect, useRef } from 'react';
export function getTargetElement(target, defaultElement) {
  if (!target) {
    return defaultElement;
  }

  var targetElement;

  if (typeof target === 'function') {
    targetElement = target();
  } else if ('current' in target) {
    targetElement = target.current;
  } else {
    targetElement = target;
  }

  return targetElement;
} // 鼠标点击事件，click 不会监听右键

var defaultEvent = 'click';
export default function useClickAway(target, onClickAway) {
  var eventName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultEvent;
  var isEmit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
  var onClickAwayRef = useRef(onClickAway);
  onClickAwayRef.current = onClickAway;
  useEffect(function () {
    var handler = function handler(event) {
      var targets = Array.isArray(target) ? target : [target];

      if (targets.some(function (targetItem) {
        var targetElement = getTargetElement(targetItem);
        return !targetElement || (targetElement === null || targetElement === void 0 ? void 0 : targetElement.contains(event.target));
      })) {
        return;
      }

      onClickAwayRef.current(event);
    };

    if (isEmit) {
      document.addEventListener(eventName, handler);
    }

    return function () {
      if (isEmit) {
        document.removeEventListener(eventName, handler);
      }
    };
  }, [target, eventName, isEmit]);
}

==> rc-ui-lib-1.3.5.tgz: package/es/hooks/use-click-away.js <==
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
import { useEffect, useRef } from 'react';
export function getTargetElement(target, defaultElement) {
  if (!target) {
    return defaultElement;
  }
  var targetElement;
  if (typeof target === 'function') {
    targetElement = target();
  } else if ('current' in target) {
    targetElement = target.current;
  } else {
    targetElement = target;
  }
  return targetElement;
}

// 鼠标点击事件，click 不会监听右键
var defaultEvent = 'click';
export default function useClickAway(target, onClickAway) {
  var eventName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultEvent;
  var isEmit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
  var onClickAwayRef = useRef(onClickAway);
  onClickAwayRef.current = onClickAway;
  useEffect(function () {
    var handler = function handler(event) {
      var targets = Array.isArray(target) ? target : [target];
      if (targets.some(function (targetItem) {
        var targetElement = getTargetElement(targetItem);
        return !targetElement || (targetElement === null || targetElement === void 0 ? void 0 : targetElement.contains(event.target));
      })) {
        return;
      }
      onClickAwayRef.current(event);
    };
    if (isEmit) {
      document.addEventListener(eventName, handler);
    }
    return function () {
      if (isEmit) {
        document.removeEventListener(eventName, handler);
      }
    };
  }, [target, eventName, isEmit]);
}
